@@ -42,7 +42,10 @@ MainWindow::MainWindow(QWidget *parent):
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow, true);
 #endif
+
+#ifndef Q_OS_SYMBIAN
     setWindowTitle("Dorian");
+#endif
 
     // Central widget. Must be an intermediate, because the book view widget
     // can be re-parented later
@@ -53,12 +56,7 @@ MainWindow::MainWindow(QWidget *parent):
     setCentralWidget(central);
 
     // Book view
-    view = new BookView(central);
-    view->show();
-    layout->addWidget(view);
-
-    // Dialogs
-    progress = new Progress(this);
+    view = new BookView(this);
 
     // Tool bar actions
 
@@ -68,13 +66,13 @@ MainWindow::MainWindow(QWidget *parent):
 #endif
 
     chaptersAction = addToolBarAction(this, SLOT(showChapters()),
-                                      "chapters", tr("Chapters"));
+                                      "chapters", tr("Chapters"), true);
     bookmarksAction = addToolBarAction(this, SLOT(showBookmarks()),
-                                       "bookmarks", tr("Bookmarks"));
+                                       "bookmarks", tr("Bookmarks"), true);
     infoAction = addToolBarAction(this, SLOT(showInfo()),
-                                  "info", tr("Book info"));
+                                  "info", tr("Book info"), true);
     libraryAction = addToolBarAction(this, SLOT(showLibrary()),
-                                     "library", tr("Library"));
+                                     "library", tr("Library"), true);
 
 #ifdef Q_WS_MAEMO_5
     settingsAction = menuBar()->addAction(tr("Settings"));
@@ -99,9 +97,10 @@ MainWindow::MainWindow(QWidget *parent):
     (void)addToolBarAction(this, SLOT(close()), "", tr("Exit"));
 #endif
 
-    // Buttons on top of the book view
-    previousButton = new TranslucentButton("back", this);
-    nextButton = new TranslucentButton("forward", this);
+    // Decorations
+    prev = new TranslucentButton("back", this);
+    next = new TranslucentButton("forward", this);
+    prog = new Progress(this);
 
     // Handle model changes
     connect(Library::instance(), SIGNAL(nowReadingChanged()),
@@ -110,7 +109,8 @@ MainWindow::MainWindow(QWidget *parent):
     // Load library, upgrade it if needed
     libraryProgress = new ProgressDialog(tr("Upgrading library"), this);
     Library *library = Library::instance();
-    connect(library, SIGNAL(beginUpgrade(int)), this, SLOT(onBeginUpgrade(int)));
+    connect(library, SIGNAL(beginUpgrade(int)),
+            this, SLOT(onBeginUpgrade(int)));
     connect(library, SIGNAL(upgrading(const QString &)),
             this, SLOT(onUpgrading(const QString &)));
     connect(library, SIGNAL(endUpgrade()), this, SLOT(onEndUpgrade()));
@@ -120,7 +120,7 @@ MainWindow::MainWindow(QWidget *parent):
     connect(view, SIGNAL(partLoadEnd(int)), this, SLOT(onPartLoadEnd(int)));
 
     // Handle progress
-    connect(view, SIGNAL(progress(qreal)), progress, SLOT(setProgress(qreal)));
+    connect(view, SIGNAL(progress(qreal)), prog, SLOT(setProgress(qreal)));
 
     // Shadow window for full screen reading
     fullScreenWindow = new FullScreenWindow(this);
@@ -131,11 +131,8 @@ MainWindow::MainWindow(QWidget *parent):
             this, SLOT(onSettingsChanged(const QString &)));
 
     // Handle book view buttons
-    connect(nextButton, SIGNAL(triggered()), this, SLOT(goToNextPage()));
-    connect(previousButton, SIGNAL(triggered()), this, SLOT(goToPreviousPage()));
-
-    // Adopt view, show window
-    showRegular();
+    connect(next, SIGNAL(triggered()), this, SLOT(goToNextPage()));
+    connect(prev, SIGNAL(triggered()), this, SLOT(goToPreviousPage()));
 
 #ifdef DORIAN_TEST_MODEL
     (void)new ModelTest(Library::instance(), this);
@@ -171,6 +168,9 @@ void MainWindow::initialize()
             library->setNowReading(sorted.mapToSource(sorted.index(0, 0)));
         }
     }
+
+    // Show in regular (non full-screen) mode
+    showRegular();
 }
 
 void MainWindow::onCurrentBookChanged()
@@ -184,48 +184,15 @@ void MainWindow::showRegular()
     TRACE;
 
     // Re-parent children
-    fullScreenWindow->leaveChildren();
-    QList<QWidget *> otherChildren;
-    otherChildren << progress << previousButton << nextButton;
-    takeChildren(view, otherChildren);
-
-    // Adjust geometry of decorations
-
-    QRect geo = geometry();
-    int y = geo.height() - progress->thickness();
-#if defined(Q_WS_MAEMO_5)
-    y -= toolBar->height();
-#endif
-    progress->setGeometry(0, y, geo.width(), y + progress->thickness());
-
-#if defined(Q_WS_MAEMO_5)
-    previousButton->setGeometry(0,
-        geo.height() - toolBar->height() - TranslucentButton::pixels,
-        TranslucentButton::pixels, TranslucentButton::pixels);
-    nextButton->setGeometry(geo.width() - TranslucentButton::pixels, 0,
-        TranslucentButton::pixels, TranslucentButton::pixels);
-#elif defined(Q_OS_SYMBIAN)
-    previousButton->setGeometry(0, geo.height() - TranslucentButton::pixels,
-        TranslucentButton::pixels, TranslucentButton::pixels);
-    nextButton->setGeometry(geo.width() - TranslucentButton::pixels,
-        0, TranslucentButton::pixels, TranslucentButton::pixels);
-#else
-    previousButton->setGeometry(0, geo.height() - TranslucentButton::pixels,
-        TranslucentButton::pixels, TranslucentButton::pixels);
-    nextButton->setGeometry(geo.width() - TranslucentButton::pixels - 25,
-        toolBar->height(), TranslucentButton::pixels,
-        TranslucentButton::pixels);
-#endif // Q_WS_MAEMO_5
-    qDebug() << "previousButton geometry" << previousButton->geometry();
+    fullScreenWindow->leaveBookView();
+    takeBookView(view, prog, prev, next);
 
     fullScreenWindow->hide();
     show();
+
 #if defined(Q_OS_SYMBIAN)
     activateWindow();
 #endif
-    progress->flash();
-    nextButton->flash();
-    previousButton->flash();
 }
 
 void MainWindow::showBig()
@@ -233,35 +200,15 @@ void MainWindow::showBig()
     TRACE;
 
     // Re-parent children
-    leaveChildren();
-    QList<QWidget *> otherChildren;
-    otherChildren << progress << nextButton << previousButton;
-    fullScreenWindow->takeChildren(view, otherChildren);
+    leaveBookView();
+    fullScreenWindow->takeBookView(view, prog, prev, next);
 
-    // Adjust geometry of decorations
-    QRect screen = QApplication::desktop()->screenGeometry();
-    int y = screen.height() - progress->thickness();
-    progress->setGeometry(0, y, screen.width(), y + progress->thickness());
-#if defined(Q_WS_MAEMO_5)
-    nextButton->setGeometry(screen.width() - TranslucentButton::pixels, 0,
-        TranslucentButton::pixels, TranslucentButton::pixels);
-#else
-    nextButton->setGeometry(screen.width() - TranslucentButton::pixels - 25, 0,
-        TranslucentButton::pixels, TranslucentButton::pixels);
-#endif // Q_WS_MAEMO_5
-    previousButton->setGeometry(0, screen.height() - TranslucentButton::pixels,
-        TranslucentButton::pixels, TranslucentButton::pixels);
-
-#ifdef Q_OS_SYMBIAN
-    hide();
-#endif
     fullScreenWindow->showFullScreen();
+    hide();
+
 #ifdef Q_OS_SYMBIAN
     fullScreenWindow->activateWindow();
 #endif
-    progress->flash();
-    nextButton->flash();
-    previousButton->flash();
 }
 
 void MainWindow::setCurrentBook(const QModelIndex &current)
@@ -308,13 +255,6 @@ void MainWindow::showBookmarks()
     }
 }
 
-void MainWindow::closeEvent(QCloseEvent *event)
-{
-    TRACE;
-    view->setLastBookmark();
-    event->accept();
-}
-
 void MainWindow::onSettingsChanged(const QString &key)
 {
 #if defined(Q_WS_MAEMO_5)
@@ -424,49 +364,6 @@ void MainWindow::timerEvent(QTimerEvent *event)
     AdopterWindow::timerEvent(event);
 }
 
-void MainWindow::resizeEvent(QResizeEvent *e)
-{
-    TRACE;
-
-    if (hasChild(progress)) {
-        qDebug() << "To" << e->size();
-        int y = e->size().height() - progress->thickness();
-#if defined(Q_WS_MAEMO_5)
-        y -= toolBar->height();
-#endif
-        progress->setGeometry(0, y, e->size().width(), y + progress->thickness());
-
-#if defined(Q_WS_MAEMO_5)
-        previousButton->setGeometry(0,
-            e->size().height() - toolBar->height() - TranslucentButton::pixels,
-            TranslucentButton::pixels, TranslucentButton::pixels);
-        nextButton->setGeometry(e->size().width() - TranslucentButton::pixels, 0,
-            TranslucentButton::pixels, TranslucentButton::pixels);
-#elif defined(Q_OS_SYMBIAN)
-        previousButton->setGeometry(0, e->size().height() - TranslucentButton::pixels,
-            TranslucentButton::pixels, TranslucentButton::pixels);
-        nextButton->setGeometry(e->size().width() - TranslucentButton::pixels,
-            0, TranslucentButton::pixels, TranslucentButton::pixels);
-#else
-        previousButton->setGeometry(0,
-            e->size().height() - TranslucentButton::pixels,
-            TranslucentButton::pixels, TranslucentButton::pixels);
-        nextButton->setGeometry(e->size().width() - TranslucentButton::pixels - 25,
-            toolBar->height(), TranslucentButton::pixels,
-            TranslucentButton::pixels);
-#endif // Q_WS_MAEMO_5
-
-#ifdef Q_WS_MAEMO_5
-        // This is needed on Maemo, in order not to lose current reading position
-        // after orientation change
-        QTimer::singleShot(250, view, SLOT(restoreLastBookmark()));
-#endif
-        previousButton->flash();
-        nextButton->flash();
-    }
-    QMainWindow::resizeEvent(e);
-}
-
 void MainWindow::about()
 {
     Dyalog *aboutDialog = new Dyalog(this, false);
@@ -479,8 +376,8 @@ void MainWindow::about()
     label->setText(tr("<b>Dorian %1</b><br><br>Copyright &copy; 2010 "
         "Akos Polster &lt;akos@pipacs.com&gt;<br>"
         "Licensed under GNU General Public License, Version 3<br>"
-        "Source code:<br><a href='https://garage.maemo.org/projects/dorian/'>"
-        "garage.maemo.org/projects/dorian</a>").arg(version));
+        "Source code:<br><a href='http://dorian.garage.maemo.org/'>"
+        "dorian.garage.maemo.org</a>").arg(version));
     aboutDialog->addWidget(label);
     aboutDialog->addStretch();
     aboutDialog->show();
@@ -488,15 +385,15 @@ void MainWindow::about()
 
 void MainWindow::goToNextPage()
 {
-    nextButton->flash();
-    previousButton->flash();
+    next->flash();
+    prev->flash();
     view->goNextPage();
 }
 
 void MainWindow::goToPreviousPage()
 {
-    nextButton->flash();
-    previousButton->flash();
+    next->flash();
+    prev->flash();
     view->goPreviousPage();
 }
 
