@@ -51,9 +51,7 @@ public slots:
     void onEndLoad();
 
 protected:
-    void closeEvent(QCloseEvent *event);
     void timerEvent(QTimerEvent *event);
-    void resizeEvent(QResizeEvent *event);
 
 private:
     void setCurrentBook(const QModelIndex &current);
@@ -72,9 +70,9 @@ private:
     QModelIndex mCurrent;
     FullScreenWindow *fullScreenWindow;
     int preventBlankingTimer;
-    Progress *progress;
-    TranslucentButton *previousButton;
-    TranslucentButton *nextButton;
+    Progress *prog;
+    TranslucentButton *prev;
+    TranslucentButton *next;
     ProgressDialog *libraryProgress;
 };
 
