@@ -35,9 +35,7 @@ public slots:
     void onGrabVolumeToggled(bool enable);
 
 protected:
-#if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
     void closeEvent(QCloseEvent *e);
-#endif
 
 private:
     QSlider *zoomSlider;
